ExceptionSanitizer typedef

ExceptionSanitizer = SanitizedSpanException Function(Object error, StackTrace stackTrace)

Callback that transforms a raw exception into sanitized span data.

Used by SpanExceptionOptions.exceptionSanitizer to control what exception information is recorded on the span.

Implementation

typedef ExceptionSanitizer =
    SanitizedSpanException Function(Object error, StackTrace stackTrace);