faro library
Classes
- App
- BatchConfig
- Browser
- DeviceId
- DeviceInfo
- Device information collected from the current device.
- Event
- Faro
- FaroAssetTracking
- Wraps the widget subtree with asset-load tracking.
- FaroConfig
- FaroException
- FaroHttpOverrides
- FaroHttpTrackingClient
- FaroLog
- FaroTrackingHttpClientRequest
- FaroTrackingHttpResponse
- FaroTransport
- FaroUser
- Represents user information for Faro telemetry.
- FaroUserInteractionWidget
- FaroWebViewBridge
- Bridges trace context and session correlation between a Flutter app and a web app running inside a WebView.
- InternalSpan
- Measurement
- Meta
- OfflineTransport
- Page
- Payload
- Sampling
- Defines how sessions should be sampled.
- SamplingContext
- Context passed to sampling functions.
- SamplingFunction
- Dynamic sampling based on context.
- SamplingRate
- Fixed sampling rate.
- SanitizedSpanException
- Sanitized exception data to record on a span.
- Sdk
- Session
- Span
- Represents a span in a distributed trace.
- SpanExceptionOptions
-
Controls how exceptions thrown from the body of
startSpanare recorded. - SpanProvider
- StackFrames
- StartUserActionOptions
- Optional configuration for starting a user action.
- Traces
- UserActionConstants
- Constants for user actions feature.
- UserActionHandle
- A handle to a user action started via Faro.startUserAction.
- UserInteractionProperties
- ViewMeta
Enums
- ContextScope
- Controls how long the span remains active in context for automatic parent assignment.
- LogLevel
- Log level enum
- SpanStatusCode
- UserActionState
- Represents the lifecycle state of a user action.
Extensions
Typedefs
-
AppRunner
= FutureOr<
void> Function() - ExceptionSanitizer = SanitizedSpanException Function(Object error, StackTrace stackTrace)
- Callback that transforms a raw exception into sanitized span data.