DeviceInfo class
Device information collected from the current device.
Constructors
Properties
- dartVersion → String
-
The Dart runtime version.
final
- deviceBrand → String
-
The device brand.
final
- deviceIsPhysical → bool
-
Whether the device is a physical device or an emulator/simulator.
final
- deviceManufacturer → String
-
The device manufacturer.
final
- deviceModel → String
-
Raw device model identifier.
final
- deviceModelName → String
-
Human-readable device model name.
final
- deviceOs → String
-
The operating system name.
final
- deviceOsDetail → String
-
Detailed operating system information.
final
- deviceOsVersion → String
-
The operating system version number.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited